@@ -71,6 +71,13 @@ ggi.add_argument('-e','--extended',
                     action="store_true",
                     help='''[Optional] If selected, file with topologies contains
                     extended trees (i.e., species instead of groups)''')
+
+ggi.add_argument('-T','--parallel_gt',
+                    action="store_true",
+                    help='''[Optional] If selected, all cores are focused to one 
+                    alignment at a time instead of one core per alignment 
+                    (i.e., default strategy)''')
+
 ggi.add_argument('-w','--write_extended',
                     action="store_true",
                     help='''[Optional] If selected, extended topologies are written and exit''')
@@ -162,7 +169,7 @@ fstats.add_argument('-t','--taxonomy',
                     metavar="",
                     type= str,
                     required=False,
-                    help='[Optional] Taxonomy file [Default: None]')                      
+                    help='[Optional] Taxonomy file is CSV (e.g., "[seq],[Group]") [Default: None]')                      
 # fstats.add_argument('-r','--reference',
 #                      metavar="",
 #                      type= str,
@@ -264,6 +271,7 @@ def main():
             threads         = wholeargs.threads,
             evomodel        = wholeargs.evomol,
             iterations      = wholeargs.iterations,
+            parallel_gt     = wholeargs.parallel_gt,
             write_extended  = wholeargs.write_extended,
             suffix          = wholeargs.suffix,
         ).main()
